@@ -25,7 +25,6 @@ from typing import (
     List,
     Optional,
     Union,
-    TYPE_CHECKING,
     cast,
     no_type_check,
 )
@@ -37,13 +36,11 @@ from pyspark.sql.types import StringType, BinaryType, ArrayType, LongType, MapTy
 from pyspark.sql import functions as F
 from pyspark.sql.functions import pandas_udf
 
+import pyspark.pandas as ps
 from pyspark.pandas.spark import functions as SF
 
-if TYPE_CHECKING:
-    import pyspark.pandas as ps  # noqa: F401 (SPARK-34943)
 
-
-class StringMethods(object):
+class StringMethods:
     """String methods for pandas-on-Spark Series"""
 
     def __init__(self, series: "ps.Series"):
@@ -74,8 +71,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_capitalize(s) -> "ps.Series[str]":
+        def pandas_capitalize(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.capitalize()
 
         return self._data.pandas_on_spark.transform_batch(pandas_capitalize)
@@ -102,8 +98,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_title(s) -> "ps.Series[str]":
+        def pandas_title(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.title()
 
         return self._data.pandas_on_spark.transform_batch(pandas_title)
@@ -176,8 +171,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_swapcase(s) -> "ps.Series[str]":
+        def pandas_swapcase(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.swapcase()
 
         return self._data.pandas_on_spark.transform_batch(pandas_swapcase)
@@ -228,8 +222,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_startswith(s) -> "ps.Series[bool]":
+        def pandas_startswith(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.startswith(pattern, na)
 
         return self._data.pandas_on_spark.transform_batch(pandas_startswith)
@@ -280,8 +273,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_endswith(s) -> "ps.Series[bool]":
+        def pandas_endswith(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.endswith(pattern, na)
 
         return self._data.pandas_on_spark.transform_batch(pandas_endswith)
@@ -333,8 +325,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_strip(s) -> "ps.Series[str]":
+        def pandas_strip(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.strip(to_strip)
 
         return self._data.pandas_on_spark.transform_batch(pandas_strip)
@@ -374,8 +365,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_lstrip(s) -> "ps.Series[str]":
+        def pandas_lstrip(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.lstrip(to_strip)
 
         return self._data.pandas_on_spark.transform_batch(pandas_lstrip)
@@ -415,8 +405,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_rstrip(s) -> "ps.Series[str]":
+        def pandas_rstrip(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.rstrip(to_strip)
 
         return self._data.pandas_on_spark.transform_batch(pandas_rstrip)
@@ -470,8 +459,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_get(s) -> "ps.Series[str]":
+        def pandas_get(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.get(i)
 
         return self._data.pandas_on_spark.transform_batch(pandas_get)
@@ -507,8 +495,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_isalnum(s) -> "ps.Series[bool]":
+        def pandas_isalnum(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.isalnum()
 
         return self._data.pandas_on_spark.transform_batch(pandas_isalnum)
@@ -533,8 +520,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_isalpha(s) -> "ps.Series[bool]":
+        def pandas_isalpha(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.isalpha()
 
         return self._data.pandas_on_spark.transform_batch(pandas_isalpha)
@@ -584,8 +570,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_isdigit(s) -> "ps.Series[bool]":
+        def pandas_isdigit(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.isdigit()
 
         return self._data.pandas_on_spark.transform_batch(pandas_isdigit)
@@ -608,8 +593,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_isspace(s) -> "ps.Series[bool]":
+        def pandas_isspace(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.isspace()
 
         return self._data.pandas_on_spark.transform_batch(pandas_isspace)
@@ -633,8 +617,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_isspace(s) -> "ps.Series[bool]":
+        def pandas_isspace(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.islower()
 
         return self._data.pandas_on_spark.transform_batch(pandas_isspace)
@@ -658,8 +641,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_isspace(s) -> "ps.Series[bool]":
+        def pandas_isspace(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.isupper()
 
         return self._data.pandas_on_spark.transform_batch(pandas_isspace)
@@ -689,8 +671,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_istitle(s) -> "ps.Series[bool]":
+        def pandas_istitle(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.istitle()
 
         return self._data.pandas_on_spark.transform_batch(pandas_istitle)
@@ -748,8 +729,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_isnumeric(s) -> "ps.Series[bool]":
+        def pandas_isnumeric(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.isnumeric()
 
         return self._data.pandas_on_spark.transform_batch(pandas_isnumeric)
@@ -799,8 +779,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_isdecimal(s) -> "ps.Series[bool]":
+        def pandas_isdecimal(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.isdecimal()
 
         return self._data.pandas_on_spark.transform_batch(pandas_isdecimal)
@@ -843,8 +822,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_center(s) -> "ps.Series[str]":
+        def pandas_center(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.center(width, fillchar)
 
         return self._data.pandas_on_spark.transform_batch(pandas_center)
@@ -963,8 +941,7 @@ class StringMethods(object):
         dtype: bool
         """
 
-        @no_type_check
-        def pandas_contains(s) -> "ps.Series[bool]":
+        def pandas_contains(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.contains(pat, case, flags, na, regex)
 
         return self._data.pandas_on_spark.transform_batch(pandas_contains)
@@ -1014,8 +991,7 @@ class StringMethods(object):
         dtype: int64
         """
 
-        @no_type_check
-        def pandas_count(s) -> "ps.Series[int]":
+        def pandas_count(s) -> ps.Series[int]:  # type: ignore[no-untyped-def]
             return s.str.count(pat, flags)
 
         return self._data.pandas_on_spark.transform_batch(pandas_count)
@@ -1098,8 +1074,7 @@ class StringMethods(object):
         dtype: int64
         """
 
-        @no_type_check
-        def pandas_find(s) -> "ps.Series[int]":
+        def pandas_find(s) -> ps.Series[int]:  # type: ignore[no-untyped-def]
             return s.str.find(sub, start, end)
 
         return self._data.pandas_on_spark.transform_batch(pandas_find)
@@ -1183,7 +1158,9 @@ class StringMethods(object):
         dtype: object
         """
         # type hint does not support to specify array type yet.
-        @pandas_udf(returnType=ArrayType(StringType(), containsNull=True))  # type: ignore
+        @pandas_udf(  # type: ignore[call-overload]
+            returnType=ArrayType(StringType(), containsNull=True)
+        )
         def pudf(s: pd.Series) -> pd.Series:
             return s.str.findall(pat, flags)
 
@@ -1227,8 +1204,7 @@ class StringMethods(object):
         >>> s.str.index('a', start=2) # doctest: +SKIP
         """
 
-        @no_type_check
-        def pandas_index(s) -> "ps.Series[np.int64]":
+        def pandas_index(s) -> ps.Series[np.int64]:  # type: ignore[no-untyped-def]
             return s.str.index(sub, start, end)
 
         return self._data.pandas_on_spark.transform_batch(pandas_index)
@@ -1277,8 +1253,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_join(s) -> "ps.Series[str]":
+        def pandas_join(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.join(sep)
 
         return self._data.pandas_on_spark.transform_batch(pandas_join)
@@ -1348,8 +1323,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_ljust(s) -> "ps.Series[str]":
+        def pandas_ljust(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.ljust(width, fillchar)
 
         return self._data.pandas_on_spark.transform_batch(pandas_ljust)
@@ -1415,8 +1389,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_match(s) -> "ps.Series[bool]":
+        def pandas_match(s) -> ps.Series[bool]:  # type: ignore[no-untyped-def]
             return s.str.match(pat, case, flags, na)
 
         return self._data.pandas_on_spark.transform_batch(pandas_match)
@@ -1439,8 +1412,7 @@ class StringMethods(object):
             A Series of normalized strings.
         """
 
-        @no_type_check
-        def pandas_normalize(s) -> "ps.Series[str]":
+        def pandas_normalize(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.normalize(form)
 
         return self._data.pandas_on_spark.transform_batch(pandas_normalize)
@@ -1488,8 +1460,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_pad(s) -> "ps.Series[str]":
+        def pandas_pad(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.pad(width, side, fillchar)
 
         return self._data.pandas_on_spark.transform_batch(pandas_pad)
@@ -1634,8 +1605,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_replace(s) -> "ps.Series[str]":
+        def pandas_replace(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.replace(pat, repl, n=n, case=case, flags=flags, regex=regex)
 
         return self._data.pandas_on_spark.transform_batch(pandas_replace)
@@ -1690,8 +1660,7 @@ class StringMethods(object):
         dtype: int64
         """
 
-        @no_type_check
-        def pandas_rfind(s) -> "ps.Series[int]":
+        def pandas_rfind(s) -> ps.Series[int]:  # type: ignore[no-untyped-def]
             return s.str.rfind(sub, start, end)
 
         return self._data.pandas_on_spark.transform_batch(pandas_rfind)
@@ -1734,8 +1703,7 @@ class StringMethods(object):
         >>> s.str.rindex('a', start=2) # doctest: +SKIP
         """
 
-        @no_type_check
-        def pandas_rindex(s) -> "ps.Series[np.int64]":
+        def pandas_rindex(s) -> ps.Series[np.int64]:  # type: ignore[no-untyped-def]
             return s.str.rindex(sub, start, end)
 
         return self._data.pandas_on_spark.transform_batch(pandas_rindex)
@@ -1776,8 +1744,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_rjust(s) -> "ps.Series[str]":
+        def pandas_rjust(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.rjust(width, fillchar)
 
         return self._data.pandas_on_spark.transform_batch(pandas_rjust)
@@ -1842,8 +1809,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_slice(s) -> "ps.Series[str]":
+        def pandas_slice(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.slice(start, stop, step)
 
         return self._data.pandas_on_spark.transform_batch(pandas_slice)
@@ -1919,8 +1885,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_slice_replace(s) -> "ps.Series[str]":
+        def pandas_slice_replace(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.slice_replace(start, stop, repl)
 
         return self._data.pandas_on_spark.transform_batch(pandas_slice_replace)
@@ -2055,7 +2020,7 @@ class StringMethods(object):
         # type hint does not support to specify array type yet.
         return_type = ArrayType(StringType(), containsNull=True)
 
-        @pandas_udf(returnType=return_type)  # type: ignore
+        @pandas_udf(returnType=return_type)  # type: ignore[call-overload]
         def pudf(s: pd.Series) -> pd.Series:
             return s.str.split(pat, n)
 
@@ -2202,7 +2167,7 @@ class StringMethods(object):
         # type hint does not support to specify array type yet.
         return_type = ArrayType(StringType(), containsNull=True)
 
-        @pandas_udf(returnType=return_type)  # type: ignore
+        @pandas_udf(returnType=return_type)  # type: ignore[call-overload]
         def pudf(s: pd.Series) -> pd.Series:
             return s.str.rsplit(pat, n)
 
@@ -2257,8 +2222,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_translate(s) -> "ps.Series[str]":
+        def pandas_translate(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.translate(table)
 
         return self._data.pandas_on_spark.transform_batch(pandas_translate)
@@ -2309,8 +2273,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_wrap(s) -> "ps.Series[str]":
+        def pandas_wrap(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.wrap(width, **kwargs)
 
         return self._data.pandas_on_spark.transform_batch(pandas_wrap)
@@ -2360,8 +2323,7 @@ class StringMethods(object):
         dtype: object
         """
 
-        @no_type_check
-        def pandas_zfill(s) -> "ps.Series[str]":
+        def pandas_zfill(s) -> ps.Series[str]:  # type: ignore[no-untyped-def]
             return s.str.zfill(width)
 
         return self._data.pandas_on_spark.transform_batch(pandas_zfill)
